#include <pcf8574.h>
#include <../Wire/Wire.h>



Pcf8574::Pcf8574(byte IDCode){
  chipAddress = IDCode;
  Wire.begin();
}



byte Pcf8574::ReadInput()
{
  Wire.requestFrom((int) chipAddress,1); //1 byte Read
  return(Wire.read());
}


void Pcf8574::beginTransmission(){
   Wire.beginTransmission(chipAddress);
}

void Pcf8574::endTransmission(){
  Wire.endTransmission();
}

void Pcf8574::write(byte output){
  Wire.write(output);
}





void Pcf8574::WriteOutput( byte output)
{
  Wire.beginTransmission(chipAddress); //Send ID Code
  Wire.write(output);
  //Send Data
  Wire.endTransmission();
  //Stop Condition
}



bool Pcf8574::digitalRead(byte pin){
 byte inpRead = ReadInput();
 return  (inpRead&port[pin]) > 0;
}


void Pcf8574::digitalWrite(byte pin, bool value){
  byte outpWrite;
  byte inpRead = ReadInput();
  outpWrite = inpRead | pin;
  if(value)
    outpWrite = inpRead | port[pin];
  else
    outpWrite = inpRead & ~port[pin];
  WriteOutput( outpWrite );
} 






byte Pcf8574::getBitpos(byte input){
 switch (input) {
  case 15:    
    return 0;
  case 14:    
    return 1;
  case 13:    
    return 2;
  case 11:    
    return 3;
  case 7:    
    return 4;
 }
}



byte Pcf8574::getkeypressed(){
  
  WriteOutput( B11110000 );

  byte readen = ReadInput();
  readen = readen >>4;
  byte col =   getBitpos(readen) ;

  WriteOutput( B00001111 );
  readen = ReadInput();
  byte row = getBitpos(readen) ;

  byte keyCode =  col   + ((row -1)  * 4) ;


  if(keyCode <= 16 ){
    if(keypressed) keyCode = 0;
    keypressed = true;
  }
  else { 
     keypressed = false;
     keyCode = 0;
  }

  return keyCode;
  
}




/* dot g f e d c b a */

byte Pcf8574::byteTo7seg(byte value,bool dot){

  byte dotvalue = B10000000;

  if(dot) 
    dotvalue = B00000000;

  switch (value) {
  case 0:    
    return B01000000 + dotvalue;
  case 1:    
    return B01111001  + dotvalue;
  case 2:    
    return B00100100  + dotvalue;
  case 3:    
    return B00110000  + dotvalue;
  case 4:    
    return B00011001  + dotvalue;
  case 5:    
    return B00010010  + dotvalue;
  case 6:    
    return B00000010  + dotvalue;
  case 7:    
    return B01111000  + dotvalue;
  case 8:    
    return B00000000  + dotvalue;
  case 9:    
    return B00011000  + dotvalue;
  case 10:    
    return B00001000  + dotvalue;
  case 11:    
    return B00000011  + dotvalue;
  case 12:    
    return B01000110   + dotvalue;
  case 13:    
    return B00100001  + dotvalue;
  case 14:    
    return B00000110  + dotvalue;
  case 15:    
    return B00001110  + dotvalue;
  case 16:    
    return B01111111  + dotvalue;
 }
}




void Pcf8574::write7seg(byte value,bool dot){
  WriteOutput(byteTo7seg(value,dot));
}












